#!/bin/bash
if :
then
  # File:         environment.sh
  # Name:         Kevin Crotty
  # Date:         25 Mar 2019
  # Desc:         Show the difference between environment variables and local variables
  # Usage:        source environment.sh

  # Set Colors for use in the script
  export NC='\e[0m'               # Text Reset
  export BBlack='\e[1;30m'        # Black
  export BRed='\e[1;31m'          # Red
  export BGreen='\e[1;32m'        # Green
  export BYellow='\e[1;33m'       # Yellow
  export BBlue='\e[1;34m'         # Blue
  export BPurple='\e[1;35m'       # Purple
  export BCyan='\e[1;36m'         # Cyan
  export BWhite='\e[1;37m'        # White

  function colorComment { echo -e "\n${BGreen}${1}${NC}"
  }
  function colorCommand { echo -e "${BRed}${1}${NC}"
  }
fi

reset

colorComment "#  Change the value of shell attributes and positional parameters, display the names and values of shell variables."
echo -e "${BGreen}#+ Note: The output of 'set' can be thousands of lines, so it helps to know what your looking for${NC}"
echo -e "${BRed}localVAR_1=Something${NC}"
echo -e "${BRed}localVAR_2=\"Something else\"${NC}"
echo -e "${BRed}set | grep local${NC}"
echo -e "localVAR_1=Something${NC}"
echo -e "localVAR_2=\"Something else\"${NC}\n"

colorComment "# Display Default Environament Variables"
echo -e "${BRed}env${NC}"
env | grep -v \e
echo -e "${BCyan}-- Snip --${NC}"

colorComment "# Define a Local and an Environment variable"
echo -e "${BRed}var1=\"This is in var1\" ${NC}"
var1="This is in var1"
echo -e "${BRed}export VAR2=\"This is in VAR2\" ${NC}"
export VAR2="This is in VAR2"

colorComment "# Make a script that displays both variables"
echo -e "${BRed}echo 'echo \$var1' > temp.sh ${NC}"
echo -e "${BRed}echo 'echo \$VAR2' >> temp.sh ${NC}"
echo 'echo $var1' > temp.sh
echo 'echo $VAR2' >> temp.sh
echo -e "${BRed}chmod +x temp.sh ${NC}"
chmod +x temp.sh

colorComment "# Run Script"
echo -e "${BRed}./temp.sh ${NC}"
./temp.sh

colorComment "# Source Script"
echo -e "${BRed}source temp.sh ${NC}"
source temp.sh

rm temp.sh && echo && echo
