#!/bin/bash
  : '   # File  :         awk.sh
        # Name  :         Kevin Crotty
        # Date  :         Apr2020
        # Desc  :         
        # Usage :         source awk.sh'

# --- COLOR VARIABLES AND FUNCTIONS --- #
    export NC='\e[0m'               # Text Reset
    export BBlack='\e[1;30m'        # Black
    export BRed='\e[1;31m'          # Red
    export BGreen='\e[1;32m'        # Green
    export BYellow='\e[1;33m'       # Yellow
    export BBlue='\e[1;34m'         # Blue
    export BPurple='\e[1;35m'       # Purple
    export BCyan='\e[1;36m'         # Cyan
    export BWhite='\e[1;37m'        # White

    function comm { echo -e "${BGreen}${1}${NC}"
    }
    function cli { echo -e "${Red}# ${1}${NC}"
    }
    function label { echo -e "${BBlue}${1}${NC}"
    }
    function output { echo -e "${NC}${1}\n"
    }

# --- AWK Usage --- #
reset

    comm '# Usage: awk [options] file ...'
    comm '# options:'

    output \
'-f progfile   --file=progfile
-F fs         --field-separator=fs
-v var=val    --assign=var=val'

    comm '# Field Variables (NF = Number of Fields)'
    cli "LINE='This is   a sentance         with 7 fields'"
    cli "echo \$LINE | awk '{print \$2\" -- \"\$5,\$NF}'"
    output 'is -- with fields'

    comm '# First replace field 2 with a value'
    comm '# Second print the whole line'
    cli "echo \"Hello Tom\" | awk '{\$2=\"Adam\"; print \$0}'"
    output 'Hello Adam'

    comm '# Access Environment Variables'
    cli 'export VAR1="Hello"'
    cli "awk 'BEGIN {print ENVIRON[\"VAR1\"]} {print}' /etc/passwd | head -n3"

    output \
'Hello
root:x:0:0:root:/root:/bin/bash
daemon:x:1:1:daemon:/usr/sbin:/usr/sbin/nologin'

     
    # --- AWK from a script --- #

    comm '# Create an awk script'
    cli 'cat > script.awk << EOF'

    echo -e \
"${Cyan}#!/usr/bin/awk -f
BEGIN { name=ARGV[1]; FS=":" }
{print \$1 \" home at \" \$6 from name}
EOF${NC}\n"

    cli 'chmod +x script.awk'
    cli './script.awk /etc/passwd | head -n3'

    output \
'root home at /etc/passwd
daemon home at /etc/passwd
bin home at /etc/passwd'

    cli 'awk -f script.awk /etc/passwd | head -n3'

    output \
'root home at /etc/passwd
daemon home at /etc/passwd
bin home at /etc/passwd'
