#!/bin/bash

# --- COLOR VARIABLES AND FUNCTIONS --- #
    export NC='\e[0m'               # Text Reset
    export BBlack='\e[1;30m'        # Black
    export BRed='\e[1;31m'          # Red
    export BGreen='\e[1;32m'        # Green
    export BYellow='\e[1;33m'       # Yellow
    export BBlue='\e[1;34m'         # Blue
    export BPurple='\e[1;35m'       # Purple
    export BCyan='\e[1;36m'         # Cyan
    export BWhite='\e[1;37m'        # White
    export NC='\e[0m'               # Text Reset
    export Black='\e[0;30m'         # Black
    export Red='\e[0;31m'           # Red
    export Green='\e[0;32m'         # Green
    export Yellow='\e[0;33m'        # Yellow
    export Blue='\e[0;34m'          # Blue
    export Purple='\e[0;35m'        # Purple
    export Cyan='\e[0;36m'          # Cyan
    export White='\e[0;37m'         # White

    function comm { echo -e "${BGreen}${1}${NC}" | fold -w 120 -s
    }
    function cli { echo -e "${Red}# ${1}${NC}" | fold -w 120 -s
    }
    function label { echo -e "${BBlue}${1}${NC}" | fold -w 120 -s
    }
    function output { echo -e "${NC}${1}\n" | fold -w 120 -s
    }

reset

# ----- BASH MAN PAGE ----- #
    label "\n# --- Bash Man Page --- #\n"
    comm "# Learn more about the difference between Login and Non-Login shells by checking the manpage for BASH."
    cli "man bash | grep -A20 \"A login shell is\""
    read -n 1 -s

    output \
"The following paragraphs describe how bash executes its ${BPurple}Initialization Files${NC}. If any of the files exist but cannot be read, bash reports an error.

When bash is invoked as an ${BPurple}interactive login shell${NC}, or as a ${BPurple}non-interactive shell${NC} with the ${BRed}--login ${NC}option, it first reads and executes commands from the file ${BPurple}/etc/profile ${NC}, if that file exists.

After reading that file, it looks for ${BPurple} ~/.bash_profile${NC}, ${BPurple} ~/.bash_login${NC}, and ${BPurple} ~/.profile${NC}, in that order, and reads and executes commands from the first one that exists and is readable. 

${NC}When an ${BPurple}interactive login shell${NC} exits, or a${BPurple} non-interactive login shell ${NC} executes the ${BRed} exit ${NC} builtin command, bash reads and executes commands from the file ${BPurple} ~/.bash_logout ${NC}, if it exists.

${NC}When an ${BPurple}interactive shell${NC} that is not a${BPurple} login shell ${NC} is started, bash reads and executes commands from ${BPurple} /etc/bash.bashrc ${NC} and ${BPurple} ~/.bashrc${NC}, if these files exist."

    read -n 1 -s

# ----- BASH MAN PAGE (Shell Options)----- #
    comm "# Learn more about the BASH shell options by checking the manpage for BASH."
    cli "man bash | grep -A80 'set \[+abefhkmnp'"
    read -n 1 -s
    echo -e "\n${Cyan}--The output has been trimmed for relevancy--\n"

    output \
"-h    Remember the location of commands as they are looked up for execution. This is enabled by default.
-i    If the -i option is present, the shell is interactive.
-m    Monitor mode. Job control is enabled. This option is on by default for interactive shells on systems that support it.
-B    The shell performs brace expansion (see Brace Expansion above). This is on by default.
-H    Enable ! style history substitution. This option is on by default when the shell is interactive.
-s    If the -s option is present, or if no arguments remain after option processing, then commands are read from the standard input."

    read -n 1 -s

# ----- INITIALIZATION FILES ----- #
    label "\n# --- Initialization Files in Action --- #\n"
    comm \
"# Make a test script. 
${BPurple}shopt login_shell${BGreen} will display our current shell type (login vs. non-login)
${BPurple}\$-${BGreen} will display our current shell options"

    cli "echo \"shopt login_shell\" > test.sh"
    cli "echo \"\$-\" >> test.sh\n"
    read -n 1 -s

# ----- RUN SCRIPT ----- #
    comm "# Execute the script (this will run in a different process space)"
    cli "./test.sh"

    output \
'login_shell off
hB'

    read -n 1 -s

# ----- SOURCE SCRIPT ----- #
    comm "# Source script (this will run in the SAME process space)"
    cli " source test.sh"
    
    output \
'login_shell on
himBHs'

    read -n 1 -s

# ----- FORCE RUN W/LOGIN ----- #
    comm "# Run with bash in login mode and non-interactively"
    cli "bash --login test.sh"

    output \
"You Ran ${BPurple}/etc/profile${NC}
You Ran ${BPurple}/root/.profile${NC}
You Ran ${BPurple}/root/.bashrc${NC}
login_shell on
hB"

    read -n 1 -s

# ----- FORCE INTERACTIVE ----- #
    comm "# Run with bash in non-login mode and interactively"
    cli "bash -i test.sh"

    output \
"You Ran ${BPurple}/etc/bash.bashrc${NC}
You Ran ${BPurple}/root/.bashrc${NC}
login_shell off
himB"

    read -n 1 -s

# ----- FORCE LOGIN AND INTERACTIVE ----- #
    comm "# Run with bash in login mode and interactively"
    cli "bash --login -i test.sh"

    output \
"You Ran ${BPurple}/etc/profile${NC}
You Ran ${BPurple}/etc/bash.bashrc${NC}
You Ran ${BPurple}/root/.profile${NC}
You Ran ${BPurple}/root/.bashrc${NC}
login_shell on
himB\n\n"
