#!/bin/bash
if :
then
  # File:         environment.sh
  # Name:         Kevin Crotty
  # Date:         25 Mar 2019
  # Desc:         Show the difference between environment variables and local variables
  # Usage:        source environment.sh

  # Set Colors for use in the script
  export NC='\e[0m'               # Text Reset
  export BBlack='\e[1;30m'        # Black
  export BRed='\e[1;31m'          # Red
  export BGreen='\e[1;32m'        # Green
  export BYellow='\e[1;33m'       # Yellow
  export BBlue='\e[1;34m'         # Blue
  export BPurple='\e[1;35m'       # Purple
  export BCyan='\e[1;36m'         # Cyan
  export BWhite='\e[1;37m'        # White

  function colorComment { echo -e "\n${BGreen}${1}${NC}"
  }
  function colorCommand { echo -e "${BRed}${1}${NC}"
  }
fi

reset
echo -e "${BGreen}#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#"
echo -e "${BGreen}# The ${BCyan}/proc${BGreen} directory is not actually located on your HDD because it                               #"
echo -e "#+ is actually a virtual filesystem containing information about processes running on the system.  #"
echo -e "#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#"

colorComment "# Create a persistent process in the background - Note the redirection of STDERR"
echo -e "${BRed}sleep 30m 2>/dev/null &${NC}"
echo -e "[1] ${BPurple}18025"

colorComment "# Symbolic links reveal the current working directory and executable"
echo -e "${BRed}ls -l /proc/${BPurple}18025${BRed}/${NC}"
echo -e "lrwxrwxrwx 1 root root 0 Mar 28 23:05 cwd -> /repo/os.public.cctc/os/modules/003_linux_essentials/examples/linux_essentials"
echo -e "lrwxrwxrwx 1 root root 0 Mar 28 23:05 exe -> /bin/sleep"

colorComment "# The 'cmdline' file gives more information about the command ran"
echo -e "${BRed}cat /proc/${BPurple}18025${BRed}/cmdline${NC}"
echo -e "sleep30m"

colorComment "# Viewing the File Descriptor(fd) folder confirms that STDERR is redirecting to /dev/null"
echo -e "${BRed}ls -l /proc/${BPurple}18025${BRed}/fd${NC}"
echo -e "total 0"
echo -e "lrwx------ 1 root root 64 Mar 28 23:04 0 -> /dev/pts/0"
echo -e "lrwx------ 1 root root 64 Mar 28 23:04 1 -> /dev/pts/0"
echo -e "l-wx------ 1 root root 64 Mar 28 23:04 2 -> /dev/null"

colorComment "# Displays Current CPU information"
echo -e "${BRed}cat /proc/cpuinfo${NC}"
echo -e "processor	: 0"
echo -e "vendor_id	: GenuineIntel"
echo -e "cpu family	: 6"
echo -e "model		: 158"
echo -e "model name	: Intel(R) Core(TM) i7-7700 CPU @ 3.60GHz"
echo -e "stepping	: 9"
echo -e "microcode	: 0xca"
echo -e "cpu MHz		: 800.015"
echo -e "cache size	: 8192 KB"
echo -e "physical id	: 0"
echo -e "siblings	: 8"
echo -e "core id		: 0"
echo -e "cpu cores	: 4"
echo -e "${BCyan}-- Snip --${NC}"

colorComment "# Displays current Memory Usage information"
echo -e "${BRed}cat /proc/meminfo${NC}"
echo -e "MemTotal:       32825224 kB"
echo -e "MemFree:        16867720 kB"
echo -e "MemAvailable:   23921980 kB"
echo -e "Buffers:         1198968 kB"
echo -e "Cached:          5212260 kB"
echo -e "SwapCached:            0 kB"
echo -e "Active:          9580940 kB"
echo -e "${BCyan}-- Snip --${NC}"

colorComment "# Displays command line options that GRUB used at startup"
echo -e "${BRed}cat /proc/cmdline${NC}"
echo -e "BOOT_IMAGE=/boot/vmlinuz-5.3.0-42-generic root=UUID=debcd4-bf5f-4bd9-ac1e-3ba1fcf225 ro quiet splash vt.handoff=1\n\n"
