#!/bin/bash
if : ; then
# File:         cron.sh
# Name:         Kevin Crotty
# Date:         29 Mar 2019
# Desc:         Display common usage cron and related commands
# Usage:        ./cron.sh

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}
fi

reset

colorComment "# View System Cron Job Directory"
echo -e "${BRed}ls -l /etc/cron.d ${NC}"
echo -e "total 12"
echo -e "-rw-r--r-- 1 root root 285 May 29  2017 anacron"
echo -e "-rw-r--r-- 1 root root 191 Mar  7 11:08 popularity-contest"
echo -e "-rw-r--r-- 1 root root 396 Dec 23  2017 sysstat"

colorComment "# View ${BPurple}sysstat${BGreen} system cron file"
echo -e "${BRed}cat /etc/cron.d/sysstat ${NC}"
echo -e "# The first element of the path is a directory where the debian-sa1"
echo -e "# script is located"
echo -e "PATH=/usr/lib/sysstat:/usr/sbin:/usr/sbin:/usr/bin:/sbin:/bin"
echo -e "\n# Activity reports every 10 minutes everyday"
echo -e "5-55/10 * * * * root command -v debian-sa1 > /dev/null && debian-sa1 1 1"
echo -e "\n# Additional run at 23:59 to rotate the statistics file"
echo -e "59 23 * * * root command -v debian-sa1 > /dev/null && debian-sa1 60 2"

colorComment "# View System Crontab File"
echo -e "${BRed}cat /etc/crontab ${NC}"
echo -e "# /etc/crontab: system-wide crontab"
echo -e "# Unlike any other crontab you don't have to run the 'crontab'"
echo -e "# command to install the new version when you edit this file"
echo -e "# and files in /etc/cron.d. These files also have username fields,"
echo -e "# that none of the other crontabs do.\n"
echo -e "${BPurple}SHELL=/bin/sh"
echo -e "PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin\n${NC}"
echo -e "# m h dom mon dow user	command"
echo -e "17 *	* * *	root    cd / && run-parts --report /etc/cron.hourly"
echo -e "25 6	* * *	root	test -x /usr/sbin/anacron || ( cd / && run-parts --report /etc/cron.daily )"
echo -e "47 6	* * 7	root	test -x /usr/sbin/anacron || ( cd / && run-parts --report /etc/cron.weekly )"
echo -e "52 6	1 * *	root	test -x /usr/sbin/anacron || ( cd / && run-parts --report /etc/cron.monthly )"

colorComment "# View Daily System Cron Job Directory"
echo -e "${BRed}ls -l /etc/cron.daily ${NC}"
echo -e "total 56"
echo -e "-rwxr-xr-x 1 root root  311 May 29  2017 0anacron"
echo -e "-rwxr-xr-x 1 root root 1176 Nov  2  2017 dpkg"
echo -e "-rwxr-xr-x 1 root root  372 Aug 21  2017 logrotate"
echo -e "-rwxr-xr-x 1 root root 1065 Apr  7  2018 man-db"
echo -e "-rwxr-xr-x 1 root root  249 Jan 25  2018 passwd"
echo -e "-rwxr-xr-x 1 root root  441 Dec 23  2017 sysstat"

colorComment "# View User Crontab File"
echo -e "${BRed}ls -l /var/spool/cron/crontabs/${NC}"
echo -e ".rw-------  crotty  ${BPurple}crontab${NC}  1.1 KB  Fri Mar 29 20:32:18 2019 crotty\n\n"
