#!/bin/bash
if : ; then
# File:         ps.sh
# Name:         Kevin Crotty
# Date:         19 Mar 2019
# Desc:         Display common usage of ps command
# Usage:        ./ps.sh

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}
fi

echo -e "${BRed}ps -elf | less ${BGreen}<-- Used to page through the long \'ps -elf\'output"

echo -e "\n${BRed}ps -elf | head -n5 ${BGreen}<-- Note the top 2 PPID's${NC}"
echo -e "F S UID        PID  PPID  C PRI  NI ADDR SZ WCHAN  STIME TTY          TIME CMD"
echo -e "${BPurple}4 S root         1     0  0  80   0 - 56461 ep_pol 18:23 ?        00:00:07 /sbin/init splash${NC}"
echo -e "${BPurple}1 S root         2     0  0  80   0 -     0 kthrea 18:23 ?        00:00:00 [kthreadd]${NC}"
echo -e "1 I root         3     2  0  60 -20 -     0 rescue 18:23 ?        00:00:00 [rcu_gp]"
echo -e "1 I root         4     2  0  60 -20 -     0 rescue 18:23 ?        00:00:00 [rcu_par_gp]"

echo -e "\n${BRed}ps --ppid 2 -lf | head  ${BGreen}<-- Show only kthreadd processes${NC}"
echo -e "F S UID        PID  PPID  C PRI  NI ADDR SZ WCHAN  STIME TTY          TIME CMD"
echo -e "1 I root         3     2  0  60 -20 -     0 rescue 18:23 ?        00:00:00 [rcu_gp]"
echo -e "1 I root         4     2  0  60 -20 -     0 rescue 18:23 ?        00:00:00 [rcu_par_gp]"
echo -e "1 I root         6     2  0  60 -20 -     0 worker 18:23 ?        00:00:00 [kworker/0:0H]"
echo -e "1 I root         8     2  0  60 -20 -     0 rescue 18:23 ?        00:00:00 [mm_percpu_wq]"
echo -e "1 S root         9     2  0  80   0 -     0 smpboo 18:23 ?        00:00:00 [ksoftirqd/0]"
echo -e "1 I root        10     2  0  80   0 -     0 rcu_gp 18:23 ?        00:00:01 [rcu_sched]"
echo -e "1 I root        11     2  0  80   0 -     0 rcu_gp 18:23 ?        00:00:00 [rcu_bh]"
echo -e "1 S root        12     2  0 -40   - -     0 smpboo 18:23 ?        00:00:00 [migration/0]"
echo -e "5 S root        13     2  0 -40   - -     0 smpboo 18:23 ?        00:00:00 [watchdog/0]"

echo -e "\n${BRed}ps --ppid 2 -Nlf | head  ${BGreen}<-- Show everything but kthreadd processes${NC}"
echo -e "F S UID        PID  PPID  C PRI  NI ADDR SZ WCHAN  STIME TTY          TIME CMD"
echo -e "4 S root         1     0  0  80   0 - 56461 ep_pol 18:23 ?        00:00:07 /sbin/init splash"
echo -e "1 S root         2     0  0  80   0 -     0 kthrea 18:23 ?        00:00:00 [kthreadd]"
echo -e "4 S root       310     1  0  79  -1 - 25836 ep_pol 18:23 ?        00:00:00 /lib/systemd/systemd-journald"
echo -e "4 S root       336     1  0  80   0 -  8503 ep_pol 18:23 ?        00:00:00 /lib/systemd/systemd-udevd"
echo -e "4 S systemd+   576     1  0  80   0 - 17750 ep_pol 18:23 ?        00:00:00 /lib/systemd/systemd-resolved"
echo -e "4 S systemd+   578     1  0  80   0 - 36527 ep_pol 18:23 ?        00:00:00 /lib/systemd/systemd-timesyncd"
echo -e "5 S root       609     1  0  76  -4 -  7994 ep_pol 18:23 ?        00:00:00 /sbin/auditd"
echo -e "4 S root       876     1  0  80   0 - 17678 ep_pol 18:23 ?        00:00:00 /lib/systemd/systemd-logind"
echo -e "4 S root       877     1  0  80   0 -  1138 poll_s 18:23 ?        00:00:00 /usr/sbin/acpid"

echo -e "\n${BRed}ps -elf --forest |tail ${BGreen}<-- --forest=ASCII forest${NC}"
echo -e "4 S root      1059  1020  0  80   0 - 67966 poll_s 18:23 ?        00:00:00  \_ gdm-session-worker [pam/gdm-autologin]"
echo -e "4 S dayman    1082  1059  0  80   0 - 53032 poll_s 18:23 tty1     00:00:00      \_ /usr/lib/gdm3/gdm-x-session --run-script env GNOME_SHELL_SESSION_MODE=ubuntu gnome-session --session=ubuntu"
echo -e "4 S root      1084  1082  2  80   0 - 104182 ep_pol 18:23 tty1    00:02:02          \_ /usr/lib/xorg/Xorg vt1 -displayfd 3 -auth /run/user/1000/gdm/Xauthority -background none -noreset -keeptty -verbose 3"
echo -e "0 S dayman    1123  1082  0  80   0 - 160388 poll_s 18:23 tty1    00:00:00          \_ /usr/lib/gnome-session/gnome-session-binary --session=ubuntu"
echo -e "1 S dayman    1204  1123  0  80   0 -  2826 poll_s 18:23 ?        00:00:00              \_ /usr/bin/ssh-agent /usr/bin/im-launch env GNOME_SHELL_SESSION_MODE=ubuntu gnome-session --session=ubuntu"
echo -e "0 R dayman    1230  1123 11  80   0 - 1021724 poll_s 18:23 tty1   00:09:33              \_ /usr/bin/gnome-shell"
echo -e "0 S dayman    1356  1230  0  80   0 - 108869 poll_s 18:23 tty1    00:00:10              |   \_ ibus-daemon --xim --panel disable"
echo -e "0 S dayman    1374  1356  0  80   0 - 70186 poll_s 18:23 tty1     00:00:00              |   |   \_ /usr/lib/ibus/ibus-dconf"
echo -e "0 S dayman    1688  1356  0  80   0 - 51221 poll_s 18:23 tty1     00:00:03              |   |   \_ /usr/lib/ibus/ibus-engine-simple"
echo -e "4 S dayman    2209  1230  7  80   0 - 1189865 poll_s 18:23 tty1   00:06:33              |   \_ /usr/lib/chromium-browser/chromium-browser --enable-pinch"
