#!/bin/bash
if : ; then
# File:         journal.sh
# Name:         Kevin Crotty
# Date:         4 Apr 2019
# Desc:         Demonstrate's common journalctl commands
# Usage:        ./journal.sh

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}
fi
clear

colorComment "# Display log entries related to the cron.service"
colorCommand "journalctl -u cron.service"
echo -e "-- Logs begin at Fri 2019-03-29 18:29:46 UTC, end at Fri 2019-04-05 02:03:58 UTC. --"
echo -e "Mar 29 18:30:22 debian systemd[1]: Started Regular background program processing daemon."
echo -e "Mar 29 18:30:22 debian cron[565]: (CRON) INFO (pidfile fd = 3)"
echo -e "Mar 29 18:30:22 debian cron[565]: (CRON) INFO (Running @reboot jobs)"
echo -e "Mar 29 19:17:01 debian CRON[1847]: pam_unix(cron:session): session opened for user root by (uid=0)"
echo -e "Mar 29 19:17:01 debian CRON[1848]: (root) CMD (   cd / && run-parts --report /etc/cron.hourly)"
echo -e "Mar 29 20:17:01 debian CRON[3356]: pam_unix(cron:session): session opened for user root by (uid=0)"
echo -e "Mar 29 20:17:01 debian CRON[3357]: (root) CMD (   cd / && run-parts --report /etc/cron.hourly)"



colorComment "# Display the date, then all the log entries that occured in the last hout"
colorCommand "date"
echo -e "Fri Apr  5 02:06:52 UTC 2019"
colorCommand "\njournalctl --since \"1 hour ago\""
echo -e "-- Logs begin at Fri 2019-03-29 18:29:46 UTC, end at Fri 2019-04-05 02:03:58 UTC. --"
echo -e "Apr 05 02:03:58 debian systemd[1]: Started Run anacron jobs."
echo -e "Apr 05 02:03:58 debian audit[1]: SERVICE_START pid=1 uid=0 auid=4294967295 ses=4294967295 msg='unit=anacron' comm="systemd" exe="/lib/systemd/""
echo -e "Apr 05 02:03:58 debian anacron[9816]: Anacron 2.3 started on 2019-04-05"
echo -e "Apr 05 02:03:58 debian anacron[9816]: Normal exit (0 jobs run)"
echo -e "Apr 05 02:03:58 debian audit[1]: SERVICE_STOP pid=1 uid=0 auid=4294967295 ses=4294967295 msg='unit=anacron' comm="systemd" exe="/lib/systemd/s""
echo -e "Apr 05 02:03:58 debian systemd[1]: anacron.timer: Adding 1min 5.641281s random time."

colorComment "# Display log entries related to a certain priority (TAB TAB to list)"
colorCommand "journalctl -p"
echo -e "alert    crit     debug    emerg    err      info     notice   warning"

colorCommand "journalctl -p crit"
echo -e "-- No entries --"

colorCommand "journalctl -p emerg"
echo -e "-- No entries --"

colorCommand "journalctl -p info"
echo -e "-- Logs begin at Fri 2019-03-29 18:29:46 UTC, end at Fri 2019-04-05 02:03:58 UTC. --"
echo -e "Mar 29 18:29:46 debian kernel: Linux version 4.9.0-5-amd64 (debian-kernel@lists.debian.org) (gcc version 6.3.0 20170516 (Debian 6.3.0-18) ) #"
echo -e "Mar 29 18:29:46 debian kernel: Command line: BOOT_IMAGE=/boot/vmlinuz-4.9.0-5-amd64 root=UUID=b013aeee-1206-4dc7-9f9c-05727f8ae6e5 ro biosdev"
echo -e "Mar 29 18:29:46 debian kernel: x86/fpu: Supporting XSAVE feature 0x001: 'x87 floating point registers'"
echo -e "Mar 29 18:29:46 debian kernel: x86/fpu: Supporting XSAVE feature 0x002: 'SSE registers'"
echo -e "Mar 29 18:29:46 debian kernel: x86/fpu: Supporting XSAVE feature 0x004: 'AVX registers'"
echo -e "Mar 29 18:29:46 debian kernel: x86/fpu: xstate_offset[2]:  576, xstate_sizes[2]:  256"

colorComment "# Display log entries with verbose output, and of the kernel ring buffer"
colorCommand "journalctl -o verbose -k"
echo -e "-- Logs begin at Fri 2019-03-29 18:29:46 UTC, end at Fri 2019-04-05 02:03:58 UTC. --"
echo -e "Fri 2019-03-29 18:29:46.823202 UTC [s=d1a43876717c4dba93e791b540b2616c;i=1;b=e858986c94014f65a643f3c37919b014;m=4f585a;t=5853fdafa4a22;x=8b5f"
echo -e "    _SOURCE_MONOTONIC_TIMESTAMP=0"
echo -e "    _TRANSPORT=kernel"
echo -e "    PRIORITY=5"
echo -e "    SYSLOG_FACILITY=0"
echo -e "    SYSLOG_IDENTIFIER=kernel"
echo -e "    MESSAGE=Linux version 4.9.0-5-amd64 (debian-kernel@lists.debian.org) (gcc version 6.3.0 20170516 (Debian 6.3.0-18) ) #1 SMP Debian 4.9.65"
echo -e "    _BOOT_ID=e858986c94014f65a643f3c37919b014"
echo -e "    _MACHINE_ID=3c239f5065784b5cb58eb4159356ebe2"
echo -e "    _HOSTNAME=debian"

colorComment "# Display log entries belonging to user root(0)"
colorCommand "journalctl _UID=0"
echo -e "    -- Logs begin at Fri 2019-03-29 18:29:46 UTC, end at Fri 2019-04-05 02:03:58 UTC. --"
echo -e "    Mar 29 18:29:46 debian systemd-journald[202]: Journal started"
echo -e "    Mar 29 18:29:46 debian systemd-journald[202]: Runtime journal (/run/log/journal/3c239f5065784b5cb58eb4159356ebe2) is 8.0M, max 79.8M, 71.8M f"
echo -e "    Mar 29 18:29:46 debian systemd-udevd[213]: Network interface NamePolicy= disabled on kernel command line, ignoring."
echo -e "    Mar 29 18:29:46 debian systemd[1]: Started Apply Kernel Variables."
echo -e "    Mar 29 18:29:46 debian systemd[1]: Started Remount Root and Kernel File Systems."

colorComment "# Display log entries belonging to user crotty(1001)"
colorCommand "journalctl _UID=1001"
echo -e "    -- Logs begin at Fri 2019-03-29 18:29:46 UTC, end at Fri 2019-04-05 02:03:58 UTC. --"
echo -e "    Mar 29 18:30:26 debian systemd[802]: Failed to open directory /home/crotty/.config/systemd/user, ignoring: Permission denied"
echo -e "    Mar 29 18:30:26 debian systemd[802]: Failed to open directory /home/crotty/.local/share/systemd/user, ignoring: Permission denied"
echo -e "    Mar 29 18:30:26 debian systemd[802]: Reached target Paths."
echo -e "    Mar 29 18:30:26 debian systemd[802]: Listening on GnuPG cryptographic agent and passphrase cache."
echo -e "    Mar 29 18:30:26 debian systemd[802]: Reached target Timers.\n\n"
