#!/bin/bash
if : ; then
# File:         logs.sh
# Name:         Kevin Crotty
# Date:         4 Apr 2019
# Desc:         Illustrate different log enumeration commands
# Usage:        ./logs.sh

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}
fi
clear

colorComment " # Display last 10 lines of /var/log/auth.log"
colorCommand " tail /var/log/auth.log\n"

echo -e " sshd[28272]: ${BYellow}Accepted password${NC} for root from 10.250.0.29 port 50664 ssh2${NC}"
echo -e " ${BPurple}sshd[28272]: pam_unix(sshd:session): session opened for user root by (uid=0)${NC}"
echo -e " ${BBlue}systemd-logind[531]: New session 37 of user root.${NC}"
echo -e " sshd[28272]: Received disconnect from 10.250.0.29 port 50664:11: disconnected by user${NC}"
echo -e " sshd[28272]: Disconnected from 10.250.0.29 port 50664${NC}"
echo -e " sshd[28272]: pam_unix(sshd:session): session closed for user root${NC}"
echo -e " systemd-logind[531]: Removed session 37.${NC}"
echo -e "${NC}"
colorCommand " tail /var/log/auth.log\n"
echo -e " sshd[28287]: ${BYellow}Accepted publickey${NC} for root from 10.250.0.29 port 50668 ssh2: RSA SHA256:jAj...${NC}"
echo -e " sshd[28287]: pam_unix(sshd:session): session opened for user root by (uid=0)${NC}"
echo -e " systemd-logind[531]: New session 38 of user root.${NC}"
echo -e " sshd[28287]: Received disconnect from 10.250.0.29 port 50668:11: disconnected by user${NC}"
echo -e " sshd[28287]: Disconnected from 10.250.0.29 port 50668${NC}"
echo -e " sshd[28287]: pam_unix(sshd:session): session closed for user root${NC}"
echo -e " systemd-logind[531]: Removed session 38.${NC}"
echo -e "${NC}"
colorCommand " tail -n15 /var/log/auth.log\n"
echo -e " sshd[28451]: ${BYellow}Accepted publickey${NC} for root from 10.250.0.29 port 50760 ssh2: RSA SHA256:jAj...${NC}"
echo -e " sshd[28451]: pam_unix(sshd:session): session opened for user root by (uid=0)${NC}"
echo -e " systemd-logind[531]: New session 39 of user root.${NC}"
echo -e " ${BPurple}CRON[28476]: pam_unix(cron:session): session opened for user root by (uid=0)${NC}"
echo -e " ${BBlue}su[29607]: ${BYellow}Successful su${NC} ${BBlue}for crotty by root${NC}"
echo -e " su[29607]: + /dev/pts/1 root:crotty${NC}"
echo -e " su[29607]: pam_unix(su:session): session opened for user crotty by root(uid=0)${NC}"
echo -e " su[29607]: pam_systemd(su:session): Cannot create session: Already running in a session${NC}"
echo -e " su[29616]: pam_unix(su:auth): authentication failure; logname=root uid=1002 euid=0 tty=/dev/pts/1 ruser=crotty rhost=  user=root${NC}"
echo -e " su[29616]: pam_authenticate: Authentication failure${NC}"
echo -e " su[29616]: ${BYellow}FAILED su${NC} for root by crotty${NC}"
echo -e " su[29616]: - /dev/pts/1 crotty:root${NC}"
echo -e " su[29624]: ${BYellow}Successful su${NC} for root by crotty${NC}"
echo -e " su[29624]: + /dev/pts/1 crotty:root${NC}"
echo -e " su[29624]: pam_unix(su:session): session opened for user root by root(uid=1002)${NC}"

echo

colorComment " # Display last 5 lines of /var/log/syslog"
colorCommand " tail -n5 /var/log/syslog"
echo -e ""


colorComment " # Without arguemnts 'last' displays contents of /var/log/wtmp"
colorCommand " last\n"
echo -e " root     pts/5        tmux(10165).%3   Thu Apr  4 12:56 - 13:04  (00:07)"
echo -e " root     pts/4        tmux(10165).%2   Thu Apr  4 12:55 - 13:04  (00:09)"
echo -e " root     pts/4        tmux(10165).%1   Thu Apr  4 12:54 - 12:54  (00:00)"
echo -e " root     pts/2        tmux(10165).%0   Thu Apr  4 12:54 - 13:04  (00:09)"
echo -e " crotty   pts/1        10.250.0.3       Wed Apr  3 23:53   still logged in"
echo -e " crotty   pts/3        192.168.250.54   Wed Apr  3 12:28 - 13:25 (1+00:56)"
echo -e " crotty   pts/3        192.168.250.54   Wed Apr  3 12:28 - 12:28  (00:00)"
echo -e " crotty   pts/3        10.250.0.3       Wed Apr  3 02:54 - 03:01  (00:07)"
echo -e " crotty   pts/3        10.250.0.3       Tue Apr  2 22:33 - 02:54  (04:20)"
echo -e " root     pts/2        tmux(11491).%1   Tue Apr  2 19:11 - 13:00  (17:49)"
echo -e " root     pts/1        tmux(11491).%0   Tue Apr  2 19:11 - 12:53  (17:42)"
echo
echo -e " wtmp begins Tue Apr  2 19:11:02 2019"


colorComment " # Display contents of /run/utmp"
colorCommand " last -f /run/utmp\n"
echo -e " crotty   pts/1        10.250.0.3       Wed Apr  3 23:53   still logged in"
echo -e " crotty   pts/0        192.168.250.54   Fri Mar 29 18:30   still logged in"
echo -e " reboot   system boot  4.9.0-5-amd64    Fri Mar 29 18:29   still running"
echo
echo -e " utmp begins Fri Mar 29 18:29:44 2019"

colorComment " # Display the last 5 lines of the kernel ring buffer"
colorCommand " dmesg\n"

echo -e " ${BPurple}<--Output trimmed-->\n${NC}"

echo -e " [    0.000000] Command line: BOOT_IMAGE=/boot/vmlinuz-4.9.0-5-amd64 root=UUID=b013aeee-124f... ro console=tty0${NC}"
echo -e " [    0.000000] ${BPurple}Hypervisor detected: KVM${NC}"
echo -e " [    0.026843] ${BYellow}Security Framework initialized${NC}"
echo -e " [    0.032017] ${BYellow}AppArmor: AppArmor disabled by boot time parameter${NC}"
echo -e " [    0.908733] ${BYellow}audit: initializing netlink subsys (disabled)${NC}"
echo -e " [    3.833293] systemd[1]: ${BPurple}Detected virtualization kvm.${NC}"
echo -e " [    3.835621] systemd[1]: Detected architecture x86-64.${NC}"
echo -e " [    4.042117] systemd[1]: Set hostname to <deb-server>.${NC}"
echo -e " [    6.276784] systemd[1]: Listening on udev Kernel Socket.${NC}"
echo -e " [    6.283471] systemd[1]: Listening on Journal Audit Socket.${NC}"
echo -e " [    6.705099] ${BBlue}EXT4-fs (vda1): re-mounted. Opts: errors=remount-ro${NC}"

echo -e "\n ${BPurple}<--Output trimmed-->\n${NC}"
