#!/bin/bash
if : ; then
# File:         menu_script_template.sh
# Name:         Kevin Crotty
# Date:         21 Mar 2019
# Desc:         Demo menu type script
# Usage:

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}
fi

netstatDemo () {
    reset
    colorComment "# Shows all connections (Internet and Unix)"
    colorCommand "netstat -a${NC}"
    echo -e "tcp        0      0 0.0.0.0:57621           0.0.0.0:*               LISTEN${NC}"
    echo -e "tcp        0      0 localhost:domain        0.0.0.0:*               LISTEN${NC}"
    echo -e "tcp        0      0 0.0.0.0:ssh             0.0.0.0:*               LISTEN${NC}"
    echo -e "${BCyan}-- Snip --${NC}"
    echo -e "tcp6       0      0 ip6-localhost:ipp       [::]:*                  LISTEN${NC}"
    echo -e "udp        0      0 localhost:domain        0.0.0.0:*${NC}"
    echo -e "udp        0      0 0.0.0.0:bootpc          0.0.0.0:*${NC}"
    echo -e "${BCyan}-- Snip --${NC}"
    echo -e "raw6       0      0 [::]:ipv6-icmp          [::]:*                  7${NC}"
    echo -e "Active UNIX domain sockets (servers and established)${NC}"
    echo -e "Proto RefCnt Flags       Type       State         I-Node   Path${NC}"
    echo -e "unix  2      [ ]         DGRAM                    30726    /run/user/1000/systemd/notify${NC}"
    echo -e "unix  2      [ ACC ]     SEQPACKET  LISTENING     1696     /run/udev/control${NC}"
    echo -e "${BCyan}-- Snip --${NC}"
    echo -e "unix  2      [ ACC ]     STREAM     LISTENING     28642    /tmp/.X11-unix/X0${NC}"
    echo -e "unix  2      [ ]         DGRAM                    1701     /run/systemd/journal/syslog${NC}"
    echo -e "unix  2      [ ACC ]     STREAM     LISTENING     1703     /run/systemd/journal/stdout${NC}"
    echo -e "${NC}"
    echo -e "${BGreen}# -t for TCP${NC}"
    echo -e "${BGreen}# -u for UDP${NC}"
    echo -e "${BGreen}# -l for only listening sockets${NC}"
    echo -e "${BGreen}# -p Show the PID and name of program to which socket belongs${NC}"
    echo -e "${BGreen}# -n display numeric addresses${NC}"
    colorCommand "netstat -tulpn${NC}"
    echo -e "Active Internet connections (only servers)${NC}"
    echo -e "Proto Recv-Q Send-Q Local Address           Foreign Address         State       PID/Program name${NC}"
    echo -e "tcp        0      0 0.0.0.0:57621           0.0.0.0:*               LISTEN      25139/spotify${NC}"
    echo -e "tcp        0      0 127.0.0.53:53           0.0.0.0:*               LISTEN      805/systemd-resolve${NC}"
    echo -e "tcp        0      0 0.0.0.0:22              0.0.0.0:*               LISTEN      1058/sshd${NC}"
    echo -e "tcp        0      0 127.0.0.1:631           0.0.0.0:*               LISTEN      20290/cupsd${NC}"
    echo -e "udp        0      0 127.0.0.53:53           0.0.0.0:*                           805/systemd-resolve${NC}"
    echo -e "udp        0      0 0.0.0.0:68              0.0.0.0:*                           1308/dhclient${NC}"
    echo -e "udp        0      0 0.0.0.0:631             0.0.0.0:*                           20291/cups-browsed${NC}"
    echo -e "udp        0      0 0.0.0.0:1194            0.0.0.0:*                           23663/openvpn${NC}"
    echo -e "udp        0      0 224.0.0.251:5353        0.0.0.0:*                           2031/chromium-brows${NC}"
    echo -e "${BCyan}-- Snip --${NC}\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n"

}

inetDemo () {
    reset
    colorComment "All 3 commands demonstrate different ways to view configured IP's and default routing information\n"
    colorCommand "ifconfig | grep -E \"([0-9]{1,3}\.){3}\"${NC}"
    echo -e "inet 127.0.0.1  netmask 255.0.0.0${NC}"
    echo -e "inet 10.250.0.3  netmask 255.255.252.0  destination 10.250.0.3${NC}"
    echo -e "inet 192.168.0.244  netmask 255.255.255.0  broadcast 192.168.0.255${NC}"
    echo
    colorCommand "ip a | grep -E \"([0-9]{1,3}\.){3}\"${NC}"
    echo -e "inet 127.0.0.1/8 scope host lo${NC}"
    echo -e "inet 192.168.0.244/24 brd 192.168.0.255 scope global dynamic noprefixroute wlp3s0${NC}"
    echo -e "inet 10.250.0.3/22 brd 10.250.3.255 scope global tun0${NC}"
    echo
    colorCommand "netstat -ie | grep -E \"([0-9]{1,3}\.){3}\"${NC}"
    echo -e "inet 127.0.0.1  netmask 255.0.0.0${NC}"
    echo -e "inet 10.250.0.3  netmask 255.255.252.0  destination 10.250.0.3${NC}"
    echo -e "inet 192.168.0.244  netmask 255.255.255.0  broadcast 192.168.0.255${NC}\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n"

}
lsofDemo () {
    reset
    colorComment "# Filter results by user"
    colorCommand "lsof -u root"
    echo -e "COMMAND     PID USER   FD      TYPE             DEVICE  SIZE/OFF       NODE NAME${NC}"
    echo -e "systemd       1 root  cwd       DIR               8,17      4096          2 /${NC}"
    echo -e "systemd       1 root  rtd       DIR               8,17      4096          2 /${NC}"
    echo -e "systemd       1 root  txt       REG               8,17   1595792   11410188 /lib/systemd/systemd${NC}"
    echo -e "systemd       1 root  mem       REG               8,17   1700792   11408147 /lib/x86_64-linux-gnu/libm-2.27.so${NC}"
    echo -e "systemd       1 root  mem       REG               8,17    121016   11403270 /lib/x86_64-linux-gnu/libudev.so.1.6.9${NC}"
    echo -e "${BCyan}-- snip --${NC}"
    echo -e "cron        909 root  txt       REG               8,17     47416    2237429 /usr/sbin/cron${NC}"
    echo -e "cron        909 root  mem       REG               8,17     26376    2493240 /usr/lib/x86_64-linux-gnu/gconv/gconv-modules.cache${NC}"
    echo -e "cron        909 root    0r      CHR                1,3       0t0          6 /dev/null${NC}"
    echo -e "cron        909 root    1u     unix 0xffff99b06d45b400       0t0      16336 type=STREAM${NC}"
    echo -e "cron        909 root    2u     unix 0xffff99b06d45b400       0t0      16336 type=STREAM${NC}"
    echo -e "cron        909 root    3uW     REG               0,23         4        815 /run/crond.pid${NC}"
    echo -e "${NC}"

    echo -e "${BGreen}# lsof -p to sort by file descriptor, (NOTE: 99% of the time you just pipe to grep)${NC}"
    colorCommand "lsof -d 1"
    echo -e "bash      23566              dayman    1u   CHR              136,0      0t0       3 /dev/pts/0${NC}"
    echo -e "su        23644                root    1u   CHR              136,0      0t0       3 /dev/pts/0${NC}"
    echo -e "bash      23645                root    1u   CHR              136,0      0t0       3 /dev/pts/0${NC}"
    echo -e "openvpn   23663                root    1u   CHR              136,1      0t0       4 /dev/pts/1 (deleted)${NC}"
    echo -e "spotify   25139              dayman    1u  unix 0xffff99aea4af8000      0t0   98390 type=STREAM${NC}"
    echo -e "chromium- 28718              dayman    1u  unix 0xffff99b039068c00      0t0   34667 type=STREAM${NC}"
    echo -e "atom      29573                root    1w   CHR                1,3      0t0       6 /dev/null${NC}"
    echo -e "cron      31580                root    1u  unix 0xffff99b06d45b400      0t0   16336 type=STREAM${NC}"
    echo -e "sh        31581                root    1u   REG               8,17      130 1573590 /tmp/#1573590 (deleted)${NC}"
    echo -e "sleep     31583                root    1u   REG               8,17      130 1573590 /tmp/#1573590 (deleted)${NC}"
    echo -e "lsof      31584                root    1u   CHR              136,0      0t0       3 /dev/pts/0${NC}\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n"
}

nmapDemo () {
    reset
    colorComment "# Run a FULL TCP CONNECT scan on our local machine"
    colorCommand "nmap -sT localhost${NC}"
    echo -e "${NC}"
    echo -e "Starting Nmap 7.40 ( https://nmap.org ) at 2019-04-03 23:53 UTC${NC}"
    echo -e "Nmap scan report for localhost (127.0.0.1)${NC}"
    echo -e "Host is up (0.000064s latency).${NC}"
    echo -e "Not shown: 994 closed ports${NC}"
    echo -e "PORT     STATE SERVICE${NC}"
    echo -e "22/tcp   open  ssh${NC}"
    echo -e "23/tcp   open  telnet${NC}"
    echo -e "80/tcp   open  http${NC}"
    echo -e "139/tcp  open  netbios-ssn${NC}"
    echo -e "445/tcp  open  microsoft-ds${NC}"
    echo -e "3389/tcp open  ms-wbt-server${NC}"
    echo -e "${NC}"
    echo -e "Nmap done: 1 IP address (1 host up) scanned in 0.09 seconds${NC}"
    echo -e "${NC}\n"
    colorComment "# Run a SYN STEALTH scan with OS DETECTION on our local machine"
    colorCommand "nmap -sS -O localhost${NC}"
    echo -e "Starting Nmap 7.40 ( https://nmap.org ) at 2019-04-03 23:54 UTC${NC}"
    echo -e "Nmap scan report for localhost (127.0.0.1)${NC}"
    echo -e "Host is up (0.0000080s latency).${NC}"
    echo -e "Not shown: 994 closed ports${NC}"
    echo -e "PORT     STATE SERVICE${NC}"
    echo -e "22/tcp   open  ssh${NC}"
    echo -e "23/tcp   open  telnet${NC}"
    echo -e "80/tcp   open  http${NC}"
    echo -e "139/tcp  open  netbios-ssn${NC}"
    echo -e "445/tcp  open  microsoft-ds${NC}"
    echo -e "3389/tcp open  ms-wbt-server${NC}"
    echo -e "Device type: general purpose${NC}"
    echo -e "Running: Linux 3.X|4.X${NC}"
    echo -e "OS CPE: cpe:/o:linux:linux_kernel:3 cpe:/o:linux:linux_kernel:4${NC}"
    echo -e "OS details: Linux 3.8 - 4.6${NC}"
    echo -e "Network Distance: 0 hops${NC}"
    echo -e "${NC}"
    echo -e "OS detection performed. Please report any incorrect results at https://nmap.org/submit/ .${NC}"
    echo -e "Nmap done: 1 IP address (1 host up) scanned in 4.00 seconds${NC}\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n"
}

# Make menu of options for the user
mainMenu () {

reset

while :
do
    #reset

    echo
    echo "Choose from the following options:"
    echo "----------------------------------"
    echo "  [1] Display 'netstat' Demo"
    echo "  [2] Display inet Demo"
    echo "  [3] Display 'lsof' Demo"
    echo "  [4] Display 'nmap' Demo"
    echo
    echo "  [X] to Exit : [C] to clear the Screen" && echo

    read -p "Choice: " choice
    echo

    case "$choice" in
        1       ) netstatDemo                           ;;
        2       ) inetDemo                              ;;
        3       ) lsofDemo                              ;;
        4       ) clear && nmapDemo                     ;;
        [xX]    ) exit 0                                ;;
        [cC]    ) clear                                 ;;
        *       ) echo "Please enter a valid option"    ;;
    esac
done
}
# Run the program
mainMenu
